4.58. umbra.ui.widgets.search_QLineEdit — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.58. umbra.ui.widgets.search_QLineEdit

search_QLineEdit.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Search_QLineEdit` class.

Others:

## 4.58.1. Module Attributes

`umbra.ui.widgets.search_QLineEdit.` `LOGGER`

## 4.58.2. Classes

class `umbra.ui.widgets.search_QLineEdit.` `Search_QLineEdit`(parent=None, uiSearchImage=None, uiSearchClickedImage=None, uiClearImage=None, uiClearClickedImage=None)

  Bases: `PyQt4.QtGui.QLineEdit`

  This class is a QLineEdit subclass providing a search field with clearing capabilities.

  Parameters: | parent – Widget parent. ( QObject ) uiSearchImage – Search button image path. ( String ) uiSearchClickedImage – Search button clicked image path. ( String ) uiClearImage – Clear button image path. ( String ) uiClearClickedImage – Clear button clicked image path. ( String )

  `uiSearchImage`

    This method is the property for self.__uiSearchImage attribute.

    Returns: | self.__uiSearchImage. ( String )

  `uiSearchClickedImage`

    This method is the property for self.__uiSearchClickedImage attribute.

    Returns: | self.__uiSearchClickedImage. ( String )

  `uiClearImage`

    This method is the property for self.__uiClearImage attribute.

    Returns: | self.__uiClearImage. ( String )

  `uiClearClickedImage`

    This method is the property for self.__uiClearClickedImage attribute.

    Returns: | self.__uiClearClickedImage. ( String )

  `searchActiveLabel`

    This method is the property for self.__searchActiveLabel attribute.

    Returns: | self.__searchActiveLabel. ( QPushButton )

  `clearButton`

    This method is the property for self.__clearButton attribute.

    Returns: | self.__clearButton. ( QPushButton )

  `completer`

    This method is the property for self.__completer attribute.

    Returns: | self.__completer. ( QCompleter )

  `completerVisibleItemsCount`

    This method is the property for self.__completerVisibleItemsCount attribute.

    Returns: | self.__completerVisibleItemsCount. ( Integer )

  `resizeEvent`(event)

    This method reimplements the `QLineEdit.QResizeEvent()` method.

    Parameters: | event – Resize event. ( QResizeEvent )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »